pub unsafe trait SCStreamDelegate: NSObjectProtocol {
// Provided methods
unsafe fn stream_didStopWithError(&self, stream: &SCStream, error: &NSError)
where Self: Sized + Message { ... }
unsafe fn outputVideoEffectDidStartForStream(&self, stream: &SCStream)
where Self: Sized + Message { ... }
unsafe fn outputVideoEffectDidStopForStream(&self, stream: &SCStream)
where Self: Sized + Message { ... }
unsafe fn streamDidBecomeActive(&self, stream: &SCStream)
where Self: Sized + Message { ... }
unsafe fn streamDidBecomeInactive(&self, stream: &SCStream)
where Self: Sized + Message { ... }
}SCStream only.Expand description
SCStreamDelegate
SCStreamDelegate is the object that adheres to the SCStream delegate call backs
See also Apple’s documentation
Provided Methods
Sourceunsafe fn stream_didStopWithError(&self, stream: &SCStream, error: &NSError)
unsafe fn stream_didStopWithError(&self, stream: &SCStream, error: &NSError)
stream:didStopStreamWithError:
Parameter stream: the SCStream object
Parameter error: the error denoted by the stopping of the stream
notifies the delegate that the stream has stopped and the error associated with it
Sourceunsafe fn outputVideoEffectDidStartForStream(&self, stream: &SCStream)
unsafe fn outputVideoEffectDidStartForStream(&self, stream: &SCStream)
outputVideoEffectDidStartForStream:
Parameter stream: the SCStream object
notifies the delegate that the stream’s overlay video effect has started.
Sourceunsafe fn outputVideoEffectDidStopForStream(&self, stream: &SCStream)
unsafe fn outputVideoEffectDidStopForStream(&self, stream: &SCStream)
stream:outputVideoEffectDidStart:
Parameter stream: the SCStream object
notifies the delegate that the stream’s overlay video effect has stopped.
Sourceunsafe fn streamDidBecomeActive(&self, stream: &SCStream)
unsafe fn streamDidBecomeActive(&self, stream: &SCStream)
streamDidBecomeActive:
Parameter stream: the SCStream object
notifies the delegate the first time any window that was being shared in the stream is re-opened after all the windows being shared are closed. When all the windows being shared are closed, the client will receive streamDidBecomeInactive:.
Sourceunsafe fn streamDidBecomeInactive(&self, stream: &SCStream)
unsafe fn streamDidBecomeInactive(&self, stream: &SCStream)
streamDidBecomeInactive:
Parameter stream: the SCStream object
notifies the delegate that all the windows that are currently being shared are exited. This callback occurs for all content filter types.